from_statement

Function from_statement 

pub fn from_statement<T>(statement: &Statement) -> Result<T, Error>
where T: for<'de> Deserialize<'de>,
Deserialize a type T from a BarkML Statement.

This is the main entry point for deserializing Rust data structures from BarkML statements. It supports deserializing from module, section, block, and assignment statements.

Errors

Returns an error if the statement structure doesn’t match the expected type T or if any values cannot be converted to the target types.